@@ -37,7 +37,7 @@ use SDL::Constants ();
 
 use constant D2R => CORE::atan2(1,1) / 45;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =pod
 
@@ -78,12 +78,15 @@ sub new {
 	# Key tracking
 	$self->{down} = {
 		# Move camera forwards and backwards
-		SDL::Constants::SDLK_w => 0,
-		SDL::Constants::SDLK_s => 0,
+		SDL::Constants::SDLK_w      => 0,
+		SDL::Constants::SDLK_s      => 0,
 
 		# Strafe camera left and right
-		SDL::Constants::SDLK_a => 0,
-		SDL::Constants::SDLK_d => 0,
+		SDL::Constants::SDLK_a      => 0,
+		SDL::Constants::SDLK_d      => 0,
+
+		# Shift makes us run
+		SDL::Constants::SDLK_LSHIFT => 0,
 	};
 
 	return $self;
@@ -225,6 +228,9 @@ sub move {
 	my $speed = $self->{speed} * $step;
 	my $down  = $self->{down};
 
+	# Are we running?
+	$speed = $speed * 2.5 if $down->{SDL::Constants::SDLK_LSHIFT};
+
 	# Find the camera-wards and sideways components of our velocity
 	my $move = $speed * (
 		$down->{SDL::Constants::SDLK_s} -
